import re
from pathlib import Path

MAJOR = 0
REVISION = 4
PATCH = 3
VERSION = f"{MAJOR}.{REVISION}.{PATCH}"


def write_version_py(filename: str = "popmon/version.py") -> None:
    """Write package version to version.py.

    This will ensure that the version in version.py is in sync with us.

    :param filename: The version.py to write too.
    :type filename: str
    """
    # Do not modify the indentation of version_str!
    version_str = f"""\"\"\"THIS FILE IS AUTO-GENERATED BY SETUP.PY.\"\"\"

version = \"{VERSION:s}\"
"""

    with open(filename, "w") as version_file:
        version_file.write(version_str)


def update_setup_py(filename="setup.py"):
    contents = Path(filename).read_text()
    contents = re.sub(
        r'version="[0-9]+\.[0-9]+\.[0-9]+[A-Za-z]*",', f'version="{VERSION}",', contents
    )
    Path(filename).write_text(contents)


write_version_py()
update_setup_py()
